### Encoding: latin1

### Name: Langren
### Title: van Langren's data on longitude distance between Toledo and Rome
### Aliases: Langren Langren1644 Langren.all
### Keywords: datasets
###   spatial

### ** Examples

data(Langren1644)

## Not run: 
##D require(maps)
##D require(ggplot2)
##D require(reshape)
##D require(plyr)
##D 
##D # set latitude to that of Toledo
##D Langren1644$Latitude <- 39.68
##D 
##D #          x/long   y/lat
##D bbox <- c( 38.186, -9.184,
##D            43.692, 28.674 )
##D bbox <- matrix(bbox, 2, 2, byrow=TRUE)
##D 
##D borders <- as.data.frame(map("world", plot = FALSE,
##D   xlim = expand_range(bbox[,2], 0.2),
##D   ylim = expand_range(bbox[,1], 0.2))[c("x", "y")])
##D 
##D data(world.cities)
##D # get actual locations of Toledo & Rome
##D cities <- subset(world.cities,
##D   name %in% c("Rome", "Toledo") & country.etc %in% c("Spain", "Italy"))
##D colnames(cities)[4:5]<-c("Latitude", "Longitude")
##D 
##D mplot <- ggplot(Langren1644, aes(Longitude, Latitude) ) +
##D   geom_path(aes(x, y), borders, colour = "grey60") +
##D   geom_point(y = 40) +
##D   geom_text(aes(label = Name), y = 40.1, angle = 90, hjust = 0, size = 3)
##D mplot <- mplot +
##D         geom_segment(aes(x=-4.03, y=40, xend=30, yend=40))
##D 
##D mplot <- mplot +
##D   geom_point(data = cities, colour = "red", size = 2) +
##D   geom_text(data=cities, aes(label=name), color="red", size=3, vjust=-0.5) +
##D   coord_cartesian(xlim=bbox[,2], ylim=bbox[,1])
##D 
##D # make the plot have approximately aspect ratio = 1
##D windows(width=10, height=2)
##D mplot
## End(Not run)

if (require(ReadImages)) {
  gimage <- read.jpeg(system.file("images", "google-toledo-rome3.jpg", package="HistData"))
  plot(gimage)
  
  # pixel coordinates of Toledo and Rome in the image, measured from the bottom left corner
  toledo.map <- c(130, 59)
  rome.map <- c(505, 119)
  
  # confirm locations of Toledo and Rome
  points(rbind(toledo.map, rome.map), cex=2)
  
  # set a scale for translation of lat,long to pixel x,y
  scale <- data.frame(x=c(130, 856), y=c(52,52))
  rownames(scale)=c(0,30)
  lines(scale)
  
  xlate <- function(x) {
    130+x*726/30        
  }
  points(x=xlate(Langren1644$Longitude), y=rep(57, nrow(Langren1644)), pch=25, col="blue")
  text(x=xlate(Langren1644$Longitude), y=rep(57, nrow(Langren1644)), labels=Langren1644$Name, srt=90, adj=c(0, 0.5), cex=0.8)
}

# show variation in estimates across graphs
library(lattice)
graph <- paste(Langren.all$Author, Langren.all$Year)
dotplot(Name ~ Longitude, data=Langren.all)

dotplot( as.factor(Year) ~ Longitude, data=Langren.all, groups=Name)

dotplot(Name ~ Longitude|graph, data=Langren.all, groups=graph)





