### Name: Nightingale
### Title: Florence Nightingale's data on deaths from various causes in the
###   Crimean War
### Aliases: Nightingale
### Keywords: datasets

### ** Examples

data(Nightingale)

# For some graphs, it is more convenient to reshape death rates to long format
#  keep only Date and death rates
require(reshape)
Night<- Nightingale[,c(1,8:10)]
melted <- melt(Night, "Date")
names(melted) <- c("Date", "Cause", "Deaths")
melted$Cause <- sub("\\.rate", "", melted$Cause)
melted$Regime <- ordered( rep(c(rep('Before', 12), rep('After', 12)), 3), levels=c('Before', 'After'))
Night <- melted

# subsets, to facilitate separate plotting
Night1 <- subset(Night, Date < as.Date("1855-04-01"))
Night2 <- subset(Night, Date >= as.Date("1855-04-01"))

## Not run: 
##D require(ggplot2)
##D # Before plot
##D cxc1 <- ggplot(Night1, aes(x = factor(Date), y=Deaths, fill = Cause)) +
##D                 # do it as a stacked bar chart first
##D  geom_bar(width = 1, position="identity", color="black") +
##D                 # set scale so area ~ Deaths    
##D  scale_y_sqrt() 
##D                 # A coxcomb plot = bar chart + polar coordinates
##D cxc1 + coord_polar(start=3*pi/2) + 
##D         opts(title="Causes of Mortality in the Army in the East") + 
##D         xlab("")
##D 
##D # After plot
##D cxc2 <- ggplot(Night2, aes(x = factor(Date), y=Deaths, fill = Cause)) +
##D  geom_bar(width = 1, position="identity", color="black") +
##D  scale_y_sqrt()
##D cxc2 + coord_polar(start=3*pi/2) +
##D         opts(title="Causes of Mortality in the Army in the East") + 
##D         xlab("")
##D 
##D # do both together, with faceting
##D cxc <- ggplot(Night, aes(x = factor(Date), y=Deaths, fill = Cause)) +
##D  geom_bar(width = 1, position="identity", color="black") + 
##D  scale_y_sqrt() +
##D  facet_grid(. ~ Regime, scales="free", labeller=label_both)
##D cxc + coord_polar(start=3*pi/2) +
##D         opts(title="Causes of Mortality in the Army in the East") + 
##D         xlab("")
## End(Not run)

## What if she had made a set of line graphs?

colors <- c("blue", "red", "black")
with(Nightingale, {
        plot(Date, Disease.rate, type="n", col="blue", 
                ylab="Annual Death Rate", xlab="Date", xaxt="n",
                main="Causes of Mortality of the British Army in the East");
        # background, to separate before, after
        rect(as.Date("1854/4/1"), -10, as.Date("1855/3/1"), 
                1.02*max(Disease.rate), col="lightgray", border="transparent");
        text( as.Date("1854/4/1"), .98*max(Disease.rate), "Before Sanitary\nCommission", pos=4);
        text( as.Date("1855/4/1"), .98*max(Disease.rate), "After Sanitary\nCommission", pos=4);
        # plot the data
        points(Date, Disease.rate, type="b", col=colors[1]);
        points(Date, Wounds.rate, type="b", col=colors[2]);
        points(Date, Other.rate, type="b", col=colors[3])
        }
)
# add custom Date axis and legend
axis.Date(1, at=seq(as.Date("1854/4/1"), as.Date("1856/3/1"), "4 months"), format="%b %Y")
legend(as.Date("1855/10/20"), 700, c("Disease", "Wounds", "Other"),
        col=colors, fill=colors, title="Cause")




